@@ -11,19 +11,15 @@ from collections import OrderedDict
 from datetime import datetime
 import logging
 import re
+from urllib.parse import urljoin, urlparse
 import warnings
 import xml.etree.ElementTree as ET  # noqa:N814
-try:
-    from urlparse import urljoin, urlparse
-except ImportError:
-    # Python 3
-    from urllib.parse import urljoin, urlparse
 
 from .http_util import session_manager
 from .metadata import TDSCatalogMetadata
 
-logging.basicConfig(level=logging.ERROR)
 log = logging.getLogger(__name__)
+log.setLevel(logging.ERROR)
 
 
 class IndexableMapping(OrderedDict):
@@ -33,13 +29,25 @@ class IndexableMapping(OrderedDict):
         """Return an item either by index or name."""
         try:
             item + ''  # Raises if item not a string
-            return super(IndexableMapping, self).__getitem__(item)
+            return super().__getitem__(item)
         except TypeError:
             return list(self.values())[item]
 
 
 class DatasetCollection(IndexableMapping):
-    """Extend ``IndexableMapping`` to allow datetime-based filter queries."""
+    r"""Extend ``IndexableMapping`` to allow datetime-based filter queries.
+
+    Indexing works like a dictionary. The dataset name ('my_data.nc', a string) is the key,
+    and the value returned is an instance of ``Dataset``. Positional indexing
+    (e.g., [0]) is another valid method of indexing.
+
+    ``DatasetCollection`` is commonly encountered as the ``datasets`` attribute of a
+    ``TDSCatalog``. If a ``regex`` in ``filter_time_nearest`` or ```filter_time_range` does not
+    provide sufficient flexibility, or the ``TDSCatalog`` does not provide accurate times,
+    iterating over ``datasets`` can be useful as part implementing a custom filter. For
+    example, in ``for ds in catalog.datasets: print(ds)``, ``ds`` will be the dataset name, and
+    ``ds`` can be used to implement further filtering logic.
+    """
 
     default_regex = re.compile(r'(?P<year>\d{4})(?P<month>[01]\d)(?P<day>[0123]\d)_'
                                r'(?P<hour>[012]\d)(?P<minute>[0-5]\d)')
@@ -47,10 +55,7 @@ class DatasetCollection(IndexableMapping):
     def _get_datasets_with_times(self, regex, strptime=None):
         # Set the default regex if we don't have one
         # If strptime is provided, pass the regex group named 'strptime' to strptime
-        if regex is None:
-            regex = self.default_regex
-        else:
-            regex = re.compile(regex)
+        regex = self.default_regex if regex is None else re.compile(regex)
 
         # Loop over the collection looking for keys that match our regex
         found_date = False
@@ -108,6 +113,7 @@ class DatasetCollection(IndexableMapping):
 
         Returns
         -------
+        Dataset
             The value with a time closest to that desired
 
         """
@@ -144,12 +150,13 @@ class DatasetCollection(IndexableMapping):
 
         Returns
         -------
+        List[Dataset]
             All values corresponding to times within the specified range
 
         """
         if start > end:
             warnings.warn('The provided start time comes after the end time. No data will '
-                          'be returned.', UserWarning)
+                          'be returned.', UserWarning, stacklevel=2)
         return [item[-1] for item in self._get_datasets_with_times(regex, strptime)
                 if start <= item[0] <= end]
 
@@ -209,42 +216,42 @@ class CaseInsensitiveDict(dict):
 
     def __init__(self, *args, **kwargs):
         """Create a dict with a set of lowercase keys."""
-        super(CaseInsensitiveDict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._keys_to_lower()
 
     def __eq__(self, other):
         """Return true if other is case-insensitive equal to self."""
-        return super(CaseInsensitiveDict, self).__eq__(CaseInsensitiveDict(other))
+        return super().__eq__(CaseInsensitiveDict(other))
 
     def __getitem__(self, key):
         """Return value from case-insensitive lookup of ``key``."""
-        return super(CaseInsensitiveDict, self).__getitem__(CaseInsensitiveStr(key))
+        return super().__getitem__(CaseInsensitiveStr(key))
 
     def __setitem__(self, key, value):
         """Set value with lowercase ``key``."""
-        super(CaseInsensitiveDict, self).__setitem__(CaseInsensitiveStr(key), value)
+        super().__setitem__(CaseInsensitiveStr(key), value)
 
     def __delitem__(self, key):
         """Delete value associated with case-insensitive lookup of ``key``."""
-        return super(CaseInsensitiveDict, self).__delitem__(CaseInsensitiveStr(key))
+        return super().__delitem__(CaseInsensitiveStr(key))
 
     def __contains__(self, key):
         """Return true if key set includes case-insensitive ``key``."""
-        return super(CaseInsensitiveDict, self).__contains__(CaseInsensitiveStr(key))
+        return super().__contains__(CaseInsensitiveStr(key))
 
     def pop(self, key, *args, **kwargs):
         """Remove and return the value associated with case-insensitive ``key``."""
-        return super(CaseInsensitiveDict, self).pop(CaseInsensitiveStr(key))
+        return super().pop(CaseInsensitiveStr(key))
 
     def _keys_to_lower(self):
         """Convert key set to lowercase."""
         for k in list(self.keys()):
-            val = super(CaseInsensitiveDict, self).__getitem__(k)
-            super(CaseInsensitiveDict, self).__delitem__(k)
+            val = super().__getitem__(k)
+            super().__delitem__(k)
             self.__setitem__(CaseInsensitiveStr(k), val)
 
 
-class TDSCatalog(object):
+class TDSCatalog:
     """
     Parse information from a THREDDS Client Catalog.
 
@@ -289,8 +296,8 @@ class TDSCatalog(object):
         if 'html' in resp.headers['content-type']:
             import warnings
             new_url = self.catalog_url.replace('html', 'xml')
-            warnings.warn('URL {} returned HTML. Changing to: {}'.format(self.catalog_url,
-                                                                         new_url))
+            warnings.warn(f'URL {self.catalog_url} returned HTML. Changing to: {new_url}',
+                          stacklevel=2)
             self.catalog_url = new_url
             resp = self.session.get(self.catalog_url)
             resp.raise_for_status()
@@ -314,12 +321,11 @@ class TDSCatalog(object):
                 current_dataset = child.attrib['name']
                 self._process_dataset(child)
 
-                if previous_dataset:
-                    # see if the previously processed dataset has access elements as children
-                    # if so, these datasets need to be processed specially when making
-                    # access_urls
-                    if self.datasets[previous_dataset].access_element_info:
-                        self.ds_with_access_elements_to_process.append(previous_dataset)
+                # see if the previously processed dataset has access elements as children
+                # if so, these datasets need to be processed specially when making
+                # access_urls
+                if previous_dataset and self.datasets[previous_dataset].access_element_info:
+                    self.ds_with_access_elements_to_process.append(previous_dataset)
 
                 previous_dataset = current_dataset
 
@@ -330,8 +336,8 @@ class TDSCatalog(object):
             elif (tag_type == 'metadata') or (tag_type == ''):
                 self._process_metadata(child, tag_type)
             elif tag_type == 'service':
-                if CaseInsensitiveStr(child.attrib['serviceType'])\
-                        != CaseInsensitiveStr('Compound'):
+                if (CaseInsensitiveStr(child.attrib['serviceType'])
+                        != CaseInsensitiveStr('Compound')):
                     # we do not want to process single services if they
                     # are already contained within a compound service, so
                     # we need to skip over those cases.
@@ -346,6 +352,11 @@ class TDSCatalog(object):
                     service_skip = self.services[-1].number_of_subservices
                     service_skip_count = 0
 
+        # Needed if the last dataset had such info, since it's only processed looking backwards
+        # when a new dataset is encountered.
+        if previous_dataset and self.datasets[previous_dataset].access_element_info:
+            self.ds_with_access_elements_to_process.append(previous_dataset)
+
         self._process_datasets()
 
     def __str__(self):
@@ -358,9 +369,8 @@ class TDSCatalog(object):
 
     def _process_dataset(self, element):
         catalog_url = ''
-        if 'urlPath' in element.attrib:
-            if element.attrib['urlPath'] == 'latest.xml':
-                catalog_url = self.catalog_url
+        if 'urlPath' in element.attrib and element.attrib['urlPath'] == 'latest.xml':
+            catalog_url = self.catalog_url
 
         ds = Dataset(element, catalog_url=catalog_url)
         self.datasets[ds.name] = ds
@@ -380,8 +390,9 @@ class TDSCatalog(object):
             # check to see if dataset needs to have access urls created, if not,
             # remove the dataset
             has_url_path = self.datasets[ds_name].url_path is not None
-            is_ds_with_access_elements_to_process = \
+            is_ds_with_access_elements_to_process = (
                 ds_name in self.ds_with_access_elements_to_process
+            )
             if has_url_path or is_ds_with_access_elements_to_process:
                 self.datasets[ds_name].make_access_urls(
                     self.base_tds_url, self.services, metadata=self.metadata)
@@ -400,7 +411,7 @@ class TDSCatalog(object):
     __repr__ = __str__
 
 
-class CatalogRef(object):
+class CatalogRef:
     """
     An object for holding catalog references obtained from a THREDDS Client Catalog.
 
@@ -452,7 +463,7 @@ class CatalogRef(object):
     __repr__ = __str__
 
 
-class Dataset(object):
+class Dataset:
     """
     An object for holding Datasets obtained from a THREDDS Client Catalog.
 
@@ -519,24 +530,21 @@ class Dataset(object):
             resolver_xml = session_manager.urlopen(resolver_url)
             tree = ET.parse(resolver_xml)
             root = tree.getroot()
-            if 'name' in root.attrib:
-                self.catalog_name = root.attrib['name']
-            else:
-                self.catalog_name = 'No name found'
+            self.catalog_name = root.attrib.get('name', 'No name found')
             resolved_url = ''
             found = False
             for child in root.iter():
                 if not found:
                     tag_type = child.tag.split('}')[-1]
-                    if tag_type == 'dataset':
-                        if 'urlPath' in child.attrib:
-                            ds = Dataset(child)
-                            resolved_url = ds.url_path
-                            found = True
+                    if tag_type == 'dataset' and 'urlPath' in child.attrib:
+                        ds = Dataset(child)
+                        resolved_url = ds.url_path
+                        found = True
             if found:
                 return resolved_url
             else:
                 log.warning('no dataset url path found in latest.xml!')
+        return None
 
     def make_access_urls(self, catalog_url, all_services, metadata=None):
         """Make fully qualified urls for the access methods enabled on the dataset.
@@ -574,18 +582,18 @@ class Dataset(object):
                 if isinstance(service, CompoundService):
                     for subservice in service.services:
                         server_base = urljoin(server_url, subservice.base)
-                        access_urls[subservice.service_type] = urljoin(server_base,
-                                                                       self.url_path)
+                        access_urls[subservice.service_type] = server_base + self.url_path
                 else:
                     server_base = urljoin(server_url, service.base)
-                    access_urls[service.service_type] = urljoin(server_base, self.url_path)
+                    access_urls[service.service_type] = server_base + self.url_path
 
         # process access children of dataset elements
-        for service_type in self.access_element_info:
-            url_path = self.access_element_info[service_type]
-            if service_type in all_service_dict:
-                server_base = urljoin(server_url, all_service_dict[service_type].base)
-                access_urls[service_type] = urljoin(server_base, url_path)
+        for sname in self.access_element_info:
+            if sname in all_service_dict:
+                service = all_service_dict[sname]
+                url_path = self.access_element_info[sname]
+                server_base = urljoin(server_url, service.base)
+                access_urls[service.service_type] = server_base + url_path
 
         self.access_urls = access_urls
 
@@ -606,9 +614,8 @@ class Dataset(object):
         """
         if filename is None:
             filename = self.name
-        with self.remote_open() as infile:
-            with open(filename, 'wb') as outfile:
-                outfile.write(infile.read())
+        with self.remote_open() as infile, open(filename, 'wb') as outfile:
+            outfile.write(infile.read())
 
     def remote_open(self, mode='b', encoding='ascii', errors='ignore'):
         """Open the remote dataset for random access.
@@ -618,7 +625,7 @@ class Dataset(object):
 
         Parameters
         ----------
-        mode : 'b' or 't', optional
+        mode : `'b'` or `'t'`, optional
             Mode with which to open the remote data; 'b' for binary, 't' for text. Defaults
             to 'b'.
 
@@ -632,7 +639,8 @@ class Dataset(object):
 
         Returns
         -------
-        A random access, file-like object
+        fobj : file-like object
+            A random access, file-like object for reading data
 
         """
         fobj = self.access_with_service('HTTPServer')
@@ -662,7 +670,8 @@ class Dataset(object):
         if service is None:
             service = 'CdmRemote' if 'CdmRemote' in self.access_urls else 'OPENDAP'
 
-        if service not in (CaseInsensitiveStr('CdmRemote'), CaseInsensitiveStr('OPENDAP')):
+        if service not in (CaseInsensitiveStr('CdmRemote'), CaseInsensitiveStr('OPENDAP'),
+                           CaseInsensitiveStr('DODS')):
             raise ValueError(service + ' is not a valid service for remote_access')
 
         return self.access_with_service(service, use_xarray)
@@ -722,27 +731,30 @@ class Dataset(object):
                     import xarray as xr
                     provider = lambda url: xr.open_dataset(CDMRemoteStore(url))  # noqa: E731
                 except ImportError:
-                    raise ImportError('CdmRemote access needs xarray to be installed.')
+                    raise ImportError('CdmRemote access needs xarray'
+                                      'to be installed.') from None
             else:
                 from .cdmr import Dataset as CDMRDataset
                 provider = CDMRDataset
-        elif service == 'OPENDAP':
+        elif service == 'OPENDAP' or service == 'DODS':
             if use_xarray:
                 try:
                     import xarray as xr
                     provider = xr.open_dataset
                 except ImportError:
-                    raise ImportError('xarray needs to be installed if `use_xarray` is True.')
+                    raise ImportError('xarray needs to be installed if '
+                                      '`use_xarray` is True.') from None
             else:
                 try:
                     from netCDF4 import Dataset as NC4Dataset
                     provider = NC4Dataset
                 except ImportError:
-                    raise ImportError('OPENDAP access needs netCDF4-python to be installed.')
+                    raise ImportError('OPENDAP access needs netCDF4-python'
+                                      'to be installed.') from None
         elif service in self.ncss_service_names:
             from .ncss import NCSS
             provider = NCSS
-        elif service == 'HTTPServer':
+        elif service == 'HTTPServer' or service == CaseInsensitiveStr('http'):
             provider = session_manager.urlopen
         else:
             raise ValueError(service + ' is not an access method supported by Siphon')
@@ -750,12 +762,12 @@ class Dataset(object):
         try:
             return provider(self.access_urls[service])
         except KeyError:
-            raise ValueError(service + ' is not available for this dataset')
+            raise ValueError(service + ' is not available for this dataset') from None
 
     __repr__ = __str__
 
 
-class SimpleService(object):
+class SimpleService:
     """Hold information about an access service enabled on a dataset.
 
     Attributes
@@ -790,7 +802,7 @@ class SimpleService(object):
         return self.service_type == 'Resolver'
 
 
-class CompoundService(object):
+class CompoundService:
     """Hold information about compound services.
 
     Attributes
@@ -840,11 +852,8 @@ def _find_base_tds_url(catalog_url):
 
     Will retain URL scheme, host, port and username/password when present.
     """
-    url_components = urlparse(catalog_url)
-    if url_components.path:
-        return catalog_url.split(url_components.path)[0]
-    else:
-        return catalog_url
+    scheme, netloc, *_ = urlparse(catalog_url)
+    return scheme + '://' + netloc
 
 
 def get_latest_access_url(catalog_url, access_method):
