@@ -3,8 +3,6 @@
 # SPDX-License-Identifier: BSD-3-Clause
 """Handle binary stream returns in NCStream format."""
 
-from __future__ import print_function
-
 from collections import OrderedDict
 import itertools
 import logging
@@ -12,8 +10,7 @@ import zlib
 
 import numpy as np
 
-from . import cdmrfeature_pb2 as cdmrf
-from . import ncStream_pb2 as stream  # noqa
+from . import cdmrfeature_pb2 as cdmrf, ncStream_pb2 as stream
 
 MAGIC_HEADER = b'\xad\xec\xce\xda'
 MAGIC_DATA = b'\xab\xec\xce\xba'
@@ -25,8 +22,8 @@ MAGIC_ERR = b'\xab\xad\xba\xda'
 MAGIC_HEADERCOV = b'\xad\xed\xde\xda'
 MAGIC_DATACOV = b'\xab\xed\xde\xba'
 
-logging.basicConfig(level=logging.WARNING)
 log = logging.getLogger(__name__)
+log.setLevel(logging.WARNING)
 
 
 #
@@ -60,10 +57,11 @@ def read_ncstream_data(fobj):
         # Handle decompressing the bytes
         if data.compress == stream.DEFLATE:
             bin_data = zlib.decompress(bin_data)
-            assert len(bin_data) == data.uncompressedSize
+            if len(bin_data) != data.uncompressedSize:
+                log.error('Uncompressed size mismatch %d vs. %d', len(bin_data),
+                          data.uncompressedSize)
         elif data.compress != stream.NONE:
-            raise NotImplementedError('Compression type {0} not implemented!'.format(
-                data.compress))
+            raise NotImplementedError(f'Compression type {data.compress} not implemented!')
 
         # Turn bytes into an array
         return reshape_array(data, np.frombuffer(bin_data, dtype=dt))
@@ -87,8 +85,7 @@ def read_ncstream_data(fobj):
             magic = read_magic(fobj)
         return data, blocks
     else:
-        raise NotImplementedError("Don't know how to handle data type: {0}".format(
-            data.dataType))
+        raise NotImplementedError(f"Don't know how to handle data type: {data.dataType}")
 
 
 def read_ncstream_data2(fobj):
@@ -144,8 +141,7 @@ def read_messages(fobj, magic_table):
         if func is not None:
             messages.append(func(fobj))
         else:
-            log.error('Unknown magic: ' + str(' '.join('{0:02x}'.format(b)
-                                                       for b in bytearray(magic))))
+            log.error('Unknown magic: %s', ' '.join(f'{b: 02x}' for b in bytearray(magic)))
 
     return messages
 
