@@ -3,18 +3,16 @@
 # SPDX-License-Identifier: BSD-3-Clause
 """Helps support reading and parsing metadata elements from a TDS client catalog."""
 
-from __future__ import print_function
-
 import logging
 
-logging.basicConfig(level=logging.ERROR)
 log = logging.getLogger(__name__)
+log.setLevel(logging.ERROR)
 
 xlink_href_attr = '{http://www.w3.org/1999/xlink}href'
 xlink_title_attr = '{http://www.w3.org/1999/xlink}title'
 
 
-class _SimpleTypes(object):
+class _SimpleTypes:
     def __init__(self):
         self._valid = {'dataFormat': self._load_valid_data_format_types(),
                        'upOrDown': self._load_valid_up_or_down(),
@@ -165,13 +163,10 @@ class _SimpleTypes(object):
         return {type_name: val}
 
 
-class _ComplexTypes(object):
+class _ComplexTypes:
     @staticmethod
     def _get_tag_name(element):
-        if '}' in element.tag:
-            element_name = element.tag.split('}')[-1]
-        else:
-            element_name = element.tag
+        element_name = element.tag.split('}')[-1] if '}' in element.tag else element.tag
         return element_name
 
     @staticmethod
@@ -441,7 +436,7 @@ class _ComplexTypes(object):
         return data_size
 
 
-class TDSCatalogMetadata(object):
+class TDSCatalogMetadata:
     """Hold information contained in the catalog Metadata tag.
 
     Attributes
@@ -470,10 +465,7 @@ class TDSCatalogMetadata(object):
         inherited = False
         if 'inherited' in element.attrib:
             inherited = element.attrib['inherited']
-            if inherited == 'true':
-                inherited = True
-            else:
-                inherited = False
+            inherited = inherited == 'true'
 
         if metadata_in and (inherited or self._is_external_metadata_doc(element)):
             # only inherit metadata passed in if the new metadata
@@ -493,10 +485,7 @@ class TDSCatalogMetadata(object):
 
     @staticmethod
     def _get_tag_name(element):
-        if '}' in element.tag:
-            element_name = element.tag.split('}')[-1]
-        else:
-            element_name = element.tag
+        element_name = element.tag.split('}')[-1] if '}' in element.tag else element.tag
         return element_name
 
     @staticmethod
@@ -513,8 +502,8 @@ class TDSCatalogMetadata(object):
         elif handler_name in self._sts:
             return getattr(self._st, handler_name)
         else:
-            msg = 'cannot find handler for element {}'.format(handler_name)
-            log.warning(msg)
+            log.warning('cannot find handler for element %s', handler_name)
+        return None
 
     def _parse_element(self, element):
 
@@ -575,10 +564,7 @@ class TDSCatalogMetadata(object):
         md = self.metadata
         md.setdefault('documentation', {})
         if known or plain_doc:
-            if known:
-                doc_type = element.attrib['type']
-            else:
-                doc_type = 'generic'
+            doc_type = element.attrib['type'] if known else 'generic'
             md['documentation'].setdefault(doc_type, []).append(element.text)
         elif xlink_href_attr in element.attrib:
             title = element.attrib[xlink_title_attr]
