@@ -30,7 +30,7 @@ class RadarQuery(DataQuery):
 
         Parameters
         ----------
-        stns : one or more strings
+        stns : str
             One or more names of variables to request
 
         Returns
@@ -75,7 +75,7 @@ class RadarServer(HTTPEndPoint):
         xmlfile = '/dataset.xml'
         if url.endswith(xmlfile):
             url = url[:-len(xmlfile)]
-        super(RadarServer, self).__init__(url)
+        super().__init__(url)
 
     def _get_metadata(self):
         ds_cat = TDSCatalog(self.url_path('dataset.xml'))
@@ -157,8 +157,8 @@ class RadarServer(HTTPEndPoint):
             url = self._base[:-1] if self._base[-1] == '/' else self._base
             url += '?' + str(query)
             return TDSCatalog(url)
-        except ET.ParseError:
-            raise BadQueryError(self.get_catalog_raw(query))
+        except ET.ParseError as e:
+            raise BadQueryError(self.get_catalog_raw(query)) from e
 
     def get_catalog_raw(self, query):
         """Fetch THREDDS catalog XML from the radar server.
@@ -192,7 +192,7 @@ def get_radarserver_datasets(server):
 
     Parameters
     ----------
-    server : string
+    server : str
         The base URL to the THREDDS server
 
     Returns
