@@ -14,15 +14,13 @@ import pandas as pd
 from .._tools import get_wind_components
 from ..http_util import HTTPEndPoint
 
-warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created", UserWarning)
-
 
 class IAStateUpperAir(HTTPEndPoint):
     """Download and parse data from the Iowa State's upper air archive."""
 
     def __init__(self):
         """Set up endpoint."""
-        super(IAStateUpperAir, self).__init__('http://mesonet.agron.iastate.edu/json')
+        super().__init__('http://mesonet.agron.iastate.edu/json')
 
     @classmethod
     def request_data(cls, time, site_id, interp_nans=False, **kwargs):
@@ -30,7 +28,7 @@ class IAStateUpperAir(HTTPEndPoint):
 
         Parameters
         ----------
-        time : datetime
+        time : datetime.datetime
             The date and time of the desired observation.
 
         site_id : str
@@ -63,7 +61,7 @@ class IAStateUpperAir(HTTPEndPoint):
 
         Parameters
         ----------
-        time : datetime
+        time : datetime.datetime
             The date and time of the desired observation.
 
         pressure : float, optional
@@ -87,7 +85,7 @@ class IAStateUpperAir(HTTPEndPoint):
 
         Parameters
         ----------
-        time : datetime
+        time : datetime.datetime
             Date and time for which data should be downloaded
         site_id : str
             Site id for which data should be downloaded
@@ -134,16 +132,20 @@ class IAStateUpperAir(HTTPEndPoint):
                                'u_wind', 'v_wind'), how='all').reset_index(drop=True)
 
         # Add unit dictionary
-        df.units = {'pressure': 'hPa',
-                    'height': 'meter',
-                    'temperature': 'degC',
-                    'dewpoint': 'degC',
-                    'direction': 'degrees',
-                    'speed': 'knot',
-                    'u_wind': 'knot',
-                    'v_wind': 'knot',
-                    'station': None,
-                    'time': None}
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created",
+                                    UserWarning)
+            df.units = {'pressure': 'hPa',
+                        'height': 'meter',
+                        'temperature': 'degC',
+                        'dewpoint': 'degC',
+                        'direction': 'degrees',
+                        'speed': 'knot',
+                        'u_wind': 'knot',
+                        'v_wind': 'knot',
+                        'station': None,
+                        'time': None}
+
         return df
 
     def _get_data_raw(self, time, site_id, pressure=None):
@@ -151,7 +153,7 @@ class IAStateUpperAir(HTTPEndPoint):
 
         Parameters
         ----------
-        time : datetime
+        time : datetime.datetime
             Date and time for which data should be downloaded
         site_id : str
             Site id for which data should be downloaded
@@ -176,11 +178,11 @@ class IAStateUpperAir(HTTPEndPoint):
         if not (json_data['profiles'] and json_data['profiles'][0]['profile']):
             message = 'No data available '
             if time is not None:
-                message += 'for {time:%Y-%m-%d %HZ} '.format(time=time)
+                message += f'for {time: %Y-%m-%d %HZ} '
             if site_id is not None:
-                message += 'for station {stid}'.format(stid=site_id)
+                message += f'for station {site_id}'
             if pressure is not None:
-                message += 'for pressure {pres}'.format(pres=pressure)
+                message += f'for pressure {pressure}'
             message = message + '.'
             raise ValueError(message)
         return json_data
