@@ -4,8 +4,7 @@
 """Read upper air data from the Integrated Global Radiosonde Archive version 2."""
 
 import datetime
-from io import BytesIO
-from io import StringIO
+from io import BytesIO, StringIO
 import itertools
 import sys
 import warnings
@@ -17,8 +16,6 @@ import pandas as pd
 from .._tools import get_wind_components
 from ..http_util import HTTPEndPoint, HTTPError
 
-warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created", UserWarning)
-
 
 class IGRAUpperAir(HTTPEndPoint):
     """Download and parse data from NCEI's Integrated Radiosonde Archive version 2."""
@@ -30,18 +27,18 @@ class IGRAUpperAir(HTTPEndPoint):
         self.end_date = ''
         self.site_id = ''
         self.folder = ''
-        super(IGRAUpperAir, self).__init__('https://www1.ncdc.noaa.gov/pub/data/igra/')
+        super().__init__('https://www1.ncdc.noaa.gov/pub/data/igra/')
 
     @classmethod
     def request_data(cls, time, site_id, derived=False):
-        """Retreive IGRA version 2 data for one station.
+        """Retrieve IGRA version 2 data for one station.
 
         Parameters
         ----------
         site_id : str
             11-character IGRA2 station identifier.
 
-        time : datetime
+        time : datetime.datetime
            The date and time of the desired observation. If list of two times is given,
            dataframes for all dates within the two dates will be returned.
 
@@ -60,7 +57,7 @@ class IGRAUpperAir(HTTPEndPoint):
             igra2.folder = 'data/data-por/'
             igra2.suffix = igra2.suffix + '-data.txt'
 
-        if type(time) == datetime.datetime:
+        if isinstance(time, datetime.datetime):
             igra2.begin_date = time
             igra2.end_date = time
         else:
@@ -109,19 +106,16 @@ class IGRAUpperAir(HTTPEndPoint):
         # Get the data and handle if there is none matching what was requested
         try:
             resp = self.get_path(path)
-        except HTTPError:
-            raise ValueError('No data available for {time:%Y-%m-%d %HZ} '
-                             'for station {stid}.'.format(time=self.begin_date,
-                                                          stid=self.site_id))
+        except HTTPError as e:
+            raise ValueError(f'No data available for {self.begin_date:%Y-%m-%d %HZ} '
+                             f'for station {self.site_id}.') from e
 
         file_info = ZipFile(BytesIO(resp.content)).infolist()[0]
-        f = ZipFile(BytesIO(resp.content)).open(file_info)
-
-        lines = [line.decode('utf-8') for line in f.readlines()]
-
-        body, header, dates_long, dates = self._select_date_range(lines)
-
-        return body, header, dates_long, dates
+        with ZipFile(BytesIO(resp.content)) as zf:
+            f = zf.open(file_info)
+            lines = [line.decode('utf-8') for line in f.readlines()]
+            body, header, dates_long, dates = self._select_date_range(lines)
+            return body, header, dates_long, dates
 
     def _select_date_range(self, lines):
         """Identify lines containing headers within the range begin_date to end_date.
@@ -136,6 +130,9 @@ class IGRAUpperAir(HTTPEndPoint):
         num_lev = []
         dates = []
 
+        min_date = None
+        max_date = None
+
         # Get indices of headers, and make a list of dates and num_lev
         for idx, line in enumerate(lines):
             if line[0] == '#':
@@ -147,18 +144,18 @@ class IGRAUpperAir(HTTPEndPoint):
                 except ValueError:
                     date = datetime.datetime(year, month, day)
 
+                min_date = min(date, min_date) if min_date else date
+                max_date = min(date, max_date) if max_date else date
+
                 # Check date
                 if self.begin_date <= date <= self.end_date:
                     headers.append(idx)
                     num_lev.append(int(line[32:36]))
                     dates.append(date)
-                if date > self.end_date:
-                    break
 
-        if len(dates) == 0:
-            # Break if no matched dates.
-            # Could improve this later by showing the date range for the station.
-            raise ValueError('No dates match selection.')
+        if not dates:
+            raise ValueError('No dates match selection. This selection has data from '
+                             f'{min_date} to {max_date}.')
 
         # Compress body of data into a string
         begin_idx = min(headers)
@@ -206,9 +203,7 @@ class IGRAUpperAir(HTTPEndPoint):
             def _ctime_strformat(val):
                 time = val.strip().zfill(5)
 
-                if int(time) < 0:
-                    return np.nan
-                elif int(time) == 9999:
+                if int(time) < 0 or int(time) == 9999:
                     return np.nan
                 else:
                     if strformat == 'MMMSS':
@@ -368,25 +363,25 @@ class IGRAUpperAir(HTTPEndPoint):
             df = df.dropna(subset=('temperature', 'reported_relative_humidity',
                            'u_wind', 'v_wind'), how='all').reset_index(drop=True)
 
-            df.units = {'pressure': 'hPa',
-                        'reported_height': 'meter',
-                        'calculated_height': 'meter',
-                        'temperature': 'Kelvin',
-                        'temperature_gradient': 'Kelvin / kilometer',
-                        'potential_temperature': 'Kelvin',
-                        'potential_temperature_gradient': 'Kelvin / kilometer',
-                        'virtual_temperature': 'Kelvin',
-                        'virtual_potential_temperature': 'Kelvin',
-                        'vapor_pressure': 'Pascal',
-                        'saturation_vapor_pressure': 'Pascal',
-                        'reported_relative_humidity': 'percent',
-                        'calculated_relative_humidity': 'percent',
-                        'relative_humidity_gradient': 'percent / kilometer',
-                        'u_wind': 'meter / second',
-                        'u_wind_gradient': '(meter / second) / kilometer)',
-                        'v_wind': 'meter / second',
-                        'v_wind_gradient': '(meter / second) / kilometer)',
-                        'refractive_index': 'unitless'}
+            units = {'pressure': 'hPa',
+                     'reported_height': 'meter',
+                     'calculated_height': 'meter',
+                     'temperature': 'Kelvin',
+                     'temperature_gradient': 'Kelvin / kilometer',
+                     'potential_temperature': 'Kelvin',
+                     'potential_temperature_gradient': 'Kelvin / kilometer',
+                     'virtual_temperature': 'Kelvin',
+                     'virtual_potential_temperature': 'Kelvin',
+                     'vapor_pressure': 'Pascal',
+                     'saturation_vapor_pressure': 'Pascal',
+                     'reported_relative_humidity': 'percent',
+                     'calculated_relative_humidity': 'percent',
+                     'relative_humidity_gradient': 'percent / kilometer',
+                     'u_wind': 'meter / second',
+                     'u_wind_gradient': '(meter / second) / kilometer)',
+                     'v_wind': 'meter / second',
+                     'v_wind_gradient': '(meter / second) / kilometer)',
+                     'refractive_index': 'unitless'}
 
         else:
             df['u_wind'], df['v_wind'] = get_wind_components(df['speed'],
@@ -402,46 +397,56 @@ class IGRAUpperAir(HTTPEndPoint):
 
             df.drop('dewpoint_depression', axis=1, inplace=True)
 
-            df.units = {'etime': 'second',
-                        'pressure': 'hPa',
-                        'height': 'meter',
-                        'temperature': 'degC',
-                        'dewpoint': 'degC',
-                        'direction': 'degrees',
-                        'speed': 'meter / second',
-                        'u_wind': 'meter / second',
-                        'v_wind': 'meter / second'}
+            units = {'etime': 'second',
+                     'pressure': 'hPa',
+                     'height': 'meter',
+                     'temperature': 'degC',
+                     'dewpoint': 'degC',
+                     'direction': 'degrees',
+                     'speed': 'meter / second',
+                     'u_wind': 'meter / second',
+                     'v_wind': 'meter / second'}
+
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created",
+                                    UserWarning)
+            df.units = units
 
         return df
 
     def _clean_header_df(self, df):
         """Format the header dataframe and add units."""
         if self.suffix == '-drvd.txt':
-            df.units = {'release_time': 'second',
-                        'precipitable_water': 'millimeter',
-                        'inv_pressure': 'hPa',
-                        'inv_height': 'meter',
-                        'inv_strength': 'Kelvin',
-                        'mixed_layer_pressure': 'hPa',
-                        'mixed_layer_height': 'meter',
-                        'freezing_point_pressure': 'hPa',
-                        'freezing_point_height': 'meter',
-                        'lcl_pressure': 'hPa',
-                        'lcl_height': 'meter',
-                        'lfc_pressure': 'hPa',
-                        'lfc_height': 'meter',
-                        'lnb_pressure': 'hPa',
-                        'lnb_height': 'meter',
-                        'lifted_index': 'degC',
-                        'showalter_index': 'degC',
-                        'k_index': 'degC',
-                        'total_totals_index': 'degC',
-                        'cape': 'Joule / kilogram',
-                        'convective_inhibition': 'Joule / kilogram'}
+            units = {'release_time': 'second',
+                     'precipitable_water': 'millimeter',
+                     'inv_pressure': 'hPa',
+                     'inv_height': 'meter',
+                     'inv_strength': 'Kelvin',
+                     'mixed_layer_pressure': 'hPa',
+                     'mixed_layer_height': 'meter',
+                     'freezing_point_pressure': 'hPa',
+                     'freezing_point_height': 'meter',
+                     'lcl_pressure': 'hPa',
+                     'lcl_height': 'meter',
+                     'lfc_pressure': 'hPa',
+                     'lfc_height': 'meter',
+                     'lnb_pressure': 'hPa',
+                     'lnb_height': 'meter',
+                     'lifted_index': 'degC',
+                     'showalter_index': 'degC',
+                     'k_index': 'degC',
+                     'total_totals_index': 'degC',
+                     'cape': 'Joule / kilogram',
+                     'convective_inhibition': 'Joule / kilogram'}
 
         else:
-            df.units = {'release_time': 'second',
+            units = {'release_time': 'second',
                         'latitude': 'degrees',
                         'longitude': 'degrees'}
 
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', "Pandas doesn't allow columns to be created",
+                                    UserWarning)
+            df.units = units
+
         return df
