@@ -3,8 +3,6 @@
 # SPDX-License-Identifier: BSD-3-Clause
 """Provide a netCDF4-like interface on top of CDMRemote and NCStream."""
 
-from __future__ import print_function
-
 from collections import OrderedDict
 import enum
 import logging
@@ -12,11 +10,11 @@ import logging
 from .cdmremote import CDMRemote
 from .ncstream import unpack_attribute, unpack_variable
 
-logging.basicConfig(level=logging.WARNING)
 log = logging.getLogger(__name__)
+log.setLevel(logging.WARNING)
 
 
-class AttributeContainer(object):
+class AttributeContainer:
     """Unpack and provide access to attributes."""
 
     def __init__(self):
@@ -39,7 +37,7 @@ class Group(AttributeContainer):
 
     def __init__(self, parent=None):
         """Initialize a Group."""
-        super(Group, self).__init__()
+        super().__init__()
         self.groups = OrderedDict()
         self.variables = OrderedDict()
         self.dimensions = OrderedDict()
@@ -98,7 +96,7 @@ class Group(AttributeContainer):
             print_groups.append('Groups:')
             for group in self.groups.values():
                 print_groups.append(str(group))
-                print_groups.append(str('---end group---'))
+                print_groups.append('---end group---')
 
         if self.dimensions:
             print_groups.append('Dimensions:')
@@ -118,7 +116,7 @@ class Group(AttributeContainer):
         if self.ncattrs():
             print_groups.append('Attributes:')
             for att in self.ncattrs():
-                print_groups.append('\t{}: {}'.format(att, getattr(self, att)))
+                print_groups.append(f'\t{att}: {getattr(self, att)}')
         return '\n'.join(print_groups)
 
     __repr__ = __str__
@@ -129,7 +127,7 @@ class Dataset(Group):
 
     def __init__(self, url):
         """Initialize the dataset."""
-        super(Dataset, self).__init__()
+        super().__init__()
         self.cdmr = CDMRemote(url)
         self.url = url
         self._read_header()
@@ -143,7 +141,7 @@ class Dataset(Group):
 
     def __str__(self):
         """Return a string representation of the Dataset and all contained members."""
-        return self.url + '\n' + super(Dataset, self).__str__()
+        return self.url + '\n' + super().__str__()
 
     __repr__ = __str__
 
@@ -153,7 +151,7 @@ class Variable(AttributeContainer):
 
     def __init__(self, group, name):
         """Initialize the Variable."""
-        super(Variable, self).__init__()
+        super().__init__()
         self._group = group
         self.name = name
         self.dimensions = ()
@@ -225,10 +223,9 @@ class Variable(AttributeContainer):
         except TypeError:
             ind = [ind]
 
-        # Make sure we don't have too many things to index
-        if len(ind) > self.ndim:
-            # But allow a full slice on a scalar variable
-            if not (self.ndim == 0 and len(ind) == 1 and ind[0] == slice(None)):
+        # Make sure we don't have too many things to index, but allow a full slice on
+        # a scalar variable
+        if len(ind) > self.ndim and (self.ndim != 0 or len(ind) != 1 or ind[0] != slice(None)):
                 raise IndexError('Too many dimensions to index.')
 
         # Expand to a slice/ellipsis for every dimension
@@ -262,15 +259,9 @@ class Variable(AttributeContainer):
 
                 # Adjust start and stop to handle negative indexing
                 # and partial support for slicing beyond end.
-                if i.start is None:
-                    start = 0
-                else:
-                    start = self._adjust_index(dim, i.start)
+                start = 0 if i.start is None else self._adjust_index(dim, i.start)
 
-                if i.stop is None:
-                    stop = self.shape[dim]
-                else:
-                    stop = self._adjust_index(dim, i.stop)
+                stop = self.shape[dim] if i.stop is None else self._adjust_index(dim, i.stop)
 
                 # Need to create new slice for adjusted values
                 ind[dim] = slice(start, stop, i.step)
@@ -317,7 +308,7 @@ class Variable(AttributeContainer):
         groups.append('{} {}({})'.format(self.datatype, self.name,
                                          ', '.join(self.dimensions)))
         for att in self.ncattrs():
-            groups.append('\t{}: {}'.format(att, getattr(self, att)))
+            groups.append(f'\t{att}: {getattr(self, att)}')
         if self.ndim:
             if self.ndim > 1:
                 shape_str = '(' + ', '.join(str(s) for s in self.shape) + ')'
@@ -327,7 +318,7 @@ class Variable(AttributeContainer):
         return '\n'.join(groups)
 
 
-class Dimension(object):
+class Dimension:
     """Hold information about dimensions shared between variables."""
 
     def __init__(self, group, name, size=None):
@@ -345,7 +336,7 @@ class Dimension(object):
         return self._group
 
     def isunlimited(self):
-        """Return whether the dimesion is unlimited."""
+        """Return whether the dimension is unlimited."""
         return self.unlimited
 
     def load_from_stream(self, dim):
@@ -362,7 +353,7 @@ class Dimension(object):
 
     def __str__(self):
         """Return a string representation of the Dimension information."""
-        grps = ['{} '.format(type(self))]
+        grps = [f'{type(self)} ']
         if self.unlimited:
             grps.append('(unlimited): ')
 
@@ -374,7 +365,7 @@ class Dimension(object):
         if self.vlen:
             grps.append(', (vlen)')
         else:
-            grps.append(', size = {0}'.format(self.size))
+            grps.append(f', size = {self.size}')
 
         return ''.join(grps)
 
