@@ -21,7 +21,7 @@ def acis_request(method, params):
 
     ACIS Web Services is a distributed system! A call to the main URL can be
     delivered to any climate center running a public instance of the service.
-    This makes the calls efficient, but also occasionaly results in failed
+    This makes the calls efficient, but also occasionally results in failed
     calls when a server you are directed to is having problems. Generally,
     reconnecting after waiting a few seconds will resolve a problem. If problems
     are persistent, contact ACIS developers at the High Plains Regional Climate
@@ -37,11 +37,12 @@ def acis_request(method, params):
 
     Returns
     -------
-    A dictionary of data based on the JSON parameters
+    dict[str, Any]
+        A dictionary of data based on the JSON parameters
 
     Raises
     ------
-    :class: `ACIS_API_Exception`
+    `AcisApiException`
         When the API is unable to establish a connection or returns
         unparsable data.
 
@@ -54,16 +55,15 @@ def acis_request(method, params):
         response = session_manager.create_session().post(base_url + method, json=params,
                                                          timeout=timeout)
         return response.json()
-    except requests.exceptions.Timeout:
-        raise AcisApiException('Connection Timeout')
-    except requests.exceptions.TooManyRedirects:
-        raise AcisApiException('Bad URL. Check your ACIS connection method string.')
-    except ValueError:
+    except requests.exceptions.Timeout as e:
+        raise AcisApiException('Connection Timeout') from e
+    except requests.exceptions.TooManyRedirects as e:
+        raise AcisApiException('Bad URL. Check your ACIS connection method string.') from e
+    except ValueError as e:
         raise AcisApiException('No data returned! The ACIS parameter dictionary'
-                               'may be incorrectly formatted')
+                               'may be incorrectly formatted') from e
 
 
-class AcisApiException(Exception):
+class AcisApiException(Exception):  # noqa: N818
     """Handle exceptions raised by the acis_request function."""
 
-    pass
